Development
===========

As this open-source project is on an early stage, we highly encourage any contribution!

How can you contribute:
-----------------------

Give us feedback
~~~~~~~~~~~~~~~~

For general feedback, questions or ideas for improvement, please send a mail to Peter Steiner <peter.steiner@tu-dresden.de> or Azarakhsh Jalalvand <azarakhsh.jalalvand@ugent.be>.

Report bugs
~~~~~~~~~~~

Please report any bugs at the `issue tracker on GitHub`_.

If you are unsure whether the experienced behaviour is intended or a bug, please just send a mail to Peter Steiner <peter.steiner@tu-dresden.de> or Azarakhsh Jalalvand <azarakhsh.jalalvand@ugent.be> first.


Improve the documentation
~~~~~~~~~~~~~~~~~~~~~~~~~

Whenever you find something not explained well, please inform either Peter Steiner <peter.steiner@tu-dresden.de> or Azarakhsh Jalalvand <azarakhsh.jalalvand@ugent.be>.


.. _GitHub: https://github.com/TUD-STKS/PyRCN
.. _issue tracker on GitHub: https://github.com/TUD-STKS/PyRCN/issues
